Python Initialization Classes
==========

.. autoclass:: polytopewalk.FROutput
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: polytopewalk.FacialReduction
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: polytopewalk.dense.DenseCenter
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: polytopewalk.sparse.SparseCenter
   :members:
   :undoc-members:
   :show-inheritance: